@@ -21,7 +21,7 @@ class AutomationOutputProcessor:
     """  """
 
     _api_url: Union[Unset, str] = UNSET
-    _archive_record: Union[Unset, ArchiveRecord] = UNSET
+    _archive_record: Union[Unset, None, ArchiveRecord] = UNSET
     _complete_with_errors: Union[Unset, bool] = UNSET
     _created_at: Union[Unset, datetime.datetime] = UNSET
     _error_file: Union[Unset, None, Blob] = UNSET
@@ -55,9 +55,9 @@ class AutomationOutputProcessor:
 
     def to_dict(self) -> Dict[str, Any]:
         api_url = self._api_url
-        archive_record: Union[Unset, Dict[str, Any]] = UNSET
+        archive_record: Union[Unset, None, Dict[str, Any]] = UNSET
         if not isinstance(self._archive_record, Unset):
-            archive_record = self._archive_record.to_dict()
+            archive_record = self._archive_record.to_dict() if self._archive_record else None
 
         complete_with_errors = self._complete_with_errors
         created_at: Union[Unset, str] = UNSET
@@ -145,11 +145,11 @@ class AutomationOutputProcessor:
                 raise
             api_url = cast(Union[Unset, str], UNSET)
 
-        def get_archive_record() -> Union[Unset, ArchiveRecord]:
-            archive_record: Union[Unset, Union[Unset, ArchiveRecord]] = UNSET
+        def get_archive_record() -> Union[Unset, None, ArchiveRecord]:
+            archive_record = None
             _archive_record = d.pop("archiveRecord")
 
-            if not isinstance(_archive_record, Unset):
+            if _archive_record is not None and not isinstance(_archive_record, Unset):
                 archive_record = ArchiveRecord.from_dict(_archive_record)
 
             return archive_record
@@ -159,7 +159,7 @@ class AutomationOutputProcessor:
         except KeyError:
             if strict:
                 raise
-            archive_record = cast(Union[Unset, ArchiveRecord], UNSET)
+            archive_record = cast(Union[Unset, None, ArchiveRecord], UNSET)
 
         def get_complete_with_errors() -> Union[Unset, bool]:
             complete_with_errors = d.pop("completeWithErrors")
@@ -381,13 +381,13 @@ class AutomationOutputProcessor:
         self._api_url = UNSET
 
     @property
-    def archive_record(self) -> ArchiveRecord:
+    def archive_record(self) -> Optional[ArchiveRecord]:
         if isinstance(self._archive_record, Unset):
             raise NotPresentError(self, "archive_record")
         return self._archive_record
 
     @archive_record.setter
-    def archive_record(self, value: ArchiveRecord) -> None:
+    def archive_record(self, value: Optional[ArchiveRecord]) -> None:
         self._archive_record = value
 
     @archive_record.deleter
