@@ -46,6 +46,7 @@ class RequestResponseSamplesItemEntity:
     _schema: Union[Unset, None, SchemaSummary] = UNSET
     _web_url: Union[Unset, str] = UNSET
     _bases: Union[Unset, str] = UNSET
+    _helm: Union[Unset, str] = UNSET
     _nucleotide_type: Union[Unset, OligoNucleotideType] = UNSET
     _length: Union[Unset, int] = UNSET
     _allow_measured_ingredients: Union[Unset, bool] = UNSET
@@ -81,6 +82,7 @@ class RequestResponseSamplesItemEntity:
         fields.append("schema={}".format(repr(self._schema)))
         fields.append("web_url={}".format(repr(self._web_url)))
         fields.append("bases={}".format(repr(self._bases)))
+        fields.append("helm={}".format(repr(self._helm)))
         fields.append("nucleotide_type={}".format(repr(self._nucleotide_type)))
         fields.append("length={}".format(repr(self._length)))
         fields.append("allow_measured_ingredients={}".format(repr(self._allow_measured_ingredients)))
@@ -150,6 +152,7 @@ class RequestResponseSamplesItemEntity:
 
         web_url = self._web_url
         bases = self._bases
+        helm = self._helm
         nucleotide_type: Union[Unset, int] = UNSET
         if not isinstance(self._nucleotide_type, Unset):
             nucleotide_type = self._nucleotide_type.value
@@ -238,6 +241,8 @@ class RequestResponseSamplesItemEntity:
             field_dict["webURL"] = web_url
         if bases is not UNSET:
             field_dict["bases"] = bases
+        if helm is not UNSET:
+            field_dict["helm"] = helm
         if nucleotide_type is not UNSET:
             field_dict["nucleotideType"] = nucleotide_type
         if length is not UNSET:
@@ -532,6 +537,17 @@ class RequestResponseSamplesItemEntity:
                 raise
             bases = cast(Union[Unset, str], UNSET)
 
+        def get_helm() -> Union[Unset, str]:
+            helm = d.pop("helm")
+            return helm
+
+        try:
+            helm = get_helm()
+        except KeyError:
+            if strict:
+                raise
+            helm = cast(Union[Unset, str], UNSET)
+
         def get_nucleotide_type() -> Union[Unset, OligoNucleotideType]:
             nucleotide_type = UNSET
             _nucleotide_type = d.pop("nucleotideType")
@@ -712,6 +728,7 @@ class RequestResponseSamplesItemEntity:
             schema=schema,
             web_url=web_url,
             bases=bases,
+            helm=helm,
             nucleotide_type=nucleotide_type,
             length=length,
             allow_measured_ingredients=allow_measured_ingredients,
@@ -1029,6 +1046,21 @@ class RequestResponseSamplesItemEntity:
     def bases(self) -> None:
         self._bases = UNSET
 
+    @property
+    def helm(self) -> str:
+        """ Representation of the oligo in HELM syntax, including any chemical modifications """
+        if isinstance(self._helm, Unset):
+            raise NotPresentError(self, "helm")
+        return self._helm
+
+    @helm.setter
+    def helm(self, value: str) -> None:
+        self._helm = value
+
+    @helm.deleter
+    def helm(self) -> None:
+        self._helm = UNSET
+
     @property
     def nucleotide_type(self) -> OligoNucleotideType:
         """ Nucleotide type of the Oligo. """
