@@ -11,7 +11,14 @@ from ..models.benchling_app_manifest_security import BenchlingAppManifestSecurit
 from ..models.dropdown_dependency import DropdownDependency
 from ..models.entity_schema_dependency import EntitySchemaDependency
 from ..models.manifest_array_config import ManifestArrayConfig
-from ..models.manifest_scalar_config import ManifestScalarConfig
+from ..models.manifest_boolean_scalar_config import ManifestBooleanScalarConfig
+from ..models.manifest_date_scalar_config import ManifestDateScalarConfig
+from ..models.manifest_datetime_scalar_config import ManifestDatetimeScalarConfig
+from ..models.manifest_float_scalar_config import ManifestFloatScalarConfig
+from ..models.manifest_integer_scalar_config import ManifestIntegerScalarConfig
+from ..models.manifest_json_scalar_config import ManifestJsonScalarConfig
+from ..models.manifest_secure_text_scalar_config import ManifestSecureTextScalarConfig
+from ..models.manifest_text_scalar_config import ManifestTextScalarConfig
 from ..models.resource_dependency import ResourceDependency
 from ..models.schema_dependency import SchemaDependency
 from ..models.workflow_task_schema_dependency import WorkflowTaskSchemaDependency
@@ -35,8 +42,15 @@ class BenchlingAppManifestAlpha:
                 WorkflowTaskSchemaDependency,
                 DropdownDependency,
                 ResourceDependency,
-                ManifestScalarConfig,
                 ManifestArrayConfig,
+                ManifestTextScalarConfig,
+                ManifestFloatScalarConfig,
+                ManifestIntegerScalarConfig,
+                ManifestBooleanScalarConfig,
+                ManifestDateScalarConfig,
+                ManifestDatetimeScalarConfig,
+                ManifestSecureTextScalarConfig,
+                ManifestJsonScalarConfig,
                 UnknownType,
             ]
         ],
@@ -91,7 +105,28 @@ class BenchlingAppManifestAlpha:
                 elif isinstance(configuration_item_data, ResourceDependency):
                     configuration_item = configuration_item_data.to_dict()
 
-                elif isinstance(configuration_item_data, ManifestScalarConfig):
+                elif isinstance(configuration_item_data, ManifestArrayConfig):
+                    configuration_item = configuration_item_data.to_dict()
+
+                elif isinstance(configuration_item_data, ManifestTextScalarConfig):
+                    configuration_item = configuration_item_data.to_dict()
+
+                elif isinstance(configuration_item_data, ManifestFloatScalarConfig):
+                    configuration_item = configuration_item_data.to_dict()
+
+                elif isinstance(configuration_item_data, ManifestIntegerScalarConfig):
+                    configuration_item = configuration_item_data.to_dict()
+
+                elif isinstance(configuration_item_data, ManifestBooleanScalarConfig):
+                    configuration_item = configuration_item_data.to_dict()
+
+                elif isinstance(configuration_item_data, ManifestDateScalarConfig):
+                    configuration_item = configuration_item_data.to_dict()
+
+                elif isinstance(configuration_item_data, ManifestDatetimeScalarConfig):
+                    configuration_item = configuration_item_data.to_dict()
+
+                elif isinstance(configuration_item_data, ManifestSecureTextScalarConfig):
                     configuration_item = configuration_item_data.to_dict()
 
                 else:
@@ -177,8 +212,15 @@ class BenchlingAppManifestAlpha:
                     WorkflowTaskSchemaDependency,
                     DropdownDependency,
                     ResourceDependency,
-                    ManifestScalarConfig,
                     ManifestArrayConfig,
+                    ManifestTextScalarConfig,
+                    ManifestFloatScalarConfig,
+                    ManifestIntegerScalarConfig,
+                    ManifestBooleanScalarConfig,
+                    ManifestDateScalarConfig,
+                    ManifestDatetimeScalarConfig,
+                    ManifestSecureTextScalarConfig,
+                    ManifestJsonScalarConfig,
                     UnknownType,
                 ]
             ],
@@ -195,8 +237,15 @@ class BenchlingAppManifestAlpha:
                     WorkflowTaskSchemaDependency,
                     DropdownDependency,
                     ResourceDependency,
-                    ManifestScalarConfig,
                     ManifestArrayConfig,
+                    ManifestTextScalarConfig,
+                    ManifestFloatScalarConfig,
+                    ManifestIntegerScalarConfig,
+                    ManifestBooleanScalarConfig,
+                    ManifestDateScalarConfig,
+                    ManifestDatetimeScalarConfig,
+                    ManifestSecureTextScalarConfig,
+                    ManifestJsonScalarConfig,
                     UnknownType,
                 ]:
                     configuration_item: Union[
@@ -205,8 +254,15 @@ class BenchlingAppManifestAlpha:
                         WorkflowTaskSchemaDependency,
                         DropdownDependency,
                         ResourceDependency,
-                        ManifestScalarConfig,
                         ManifestArrayConfig,
+                        ManifestTextScalarConfig,
+                        ManifestFloatScalarConfig,
+                        ManifestIntegerScalarConfig,
+                        ManifestBooleanScalarConfig,
+                        ManifestDateScalarConfig,
+                        ManifestDatetimeScalarConfig,
+                        ManifestSecureTextScalarConfig,
+                        ManifestJsonScalarConfig,
                         UnknownType,
                     ]
                     discriminator_value: str = cast(str, data.get("type"))
@@ -220,7 +276,7 @@ class BenchlingAppManifestAlpha:
 
                             return configuration_item
                         if discriminator_value == "boolean":
-                            configuration_item = ManifestScalarConfig.from_dict(data, strict=False)
+                            configuration_item = ManifestBooleanScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "box":
@@ -244,11 +300,11 @@ class BenchlingAppManifestAlpha:
 
                             return configuration_item
                         if discriminator_value == "date":
-                            configuration_item = ManifestScalarConfig.from_dict(data, strict=False)
+                            configuration_item = ManifestDateScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "datetime":
-                            configuration_item = ManifestScalarConfig.from_dict(data, strict=False)
+                            configuration_item = ManifestDatetimeScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "dna_oligo":
@@ -276,7 +332,7 @@ class BenchlingAppManifestAlpha:
 
                             return configuration_item
                         if discriminator_value == "float":
-                            configuration_item = ManifestScalarConfig.from_dict(data, strict=False)
+                            configuration_item = ManifestFloatScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "folder":
@@ -284,11 +340,11 @@ class BenchlingAppManifestAlpha:
 
                             return configuration_item
                         if discriminator_value == "integer":
-                            configuration_item = ManifestScalarConfig.from_dict(data, strict=False)
+                            configuration_item = ManifestIntegerScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "json":
-                            configuration_item = ManifestScalarConfig.from_dict(data, strict=False)
+                            configuration_item = ManifestJsonScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "location":
@@ -344,11 +400,11 @@ class BenchlingAppManifestAlpha:
 
                             return configuration_item
                         if discriminator_value == "secure_text":
-                            configuration_item = ManifestScalarConfig.from_dict(data, strict=False)
+                            configuration_item = ManifestSecureTextScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "text":
-                            configuration_item = ManifestScalarConfig.from_dict(data, strict=False)
+                            configuration_item = ManifestTextScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "workflow_task_schema":
@@ -408,7 +464,7 @@ class BenchlingAppManifestAlpha:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        configuration_item = ManifestScalarConfig.from_dict(data, strict=True)
+                        configuration_item = ManifestArrayConfig.from_dict(data, strict=True)
 
                         return configuration_item
                     except:  # noqa: E722
@@ -416,7 +472,63 @@ class BenchlingAppManifestAlpha:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        configuration_item = ManifestArrayConfig.from_dict(data, strict=True)
+                        configuration_item = ManifestTextScalarConfig.from_dict(data, strict=True)
+
+                        return configuration_item
+                    except:  # noqa: E722
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        configuration_item = ManifestFloatScalarConfig.from_dict(data, strict=True)
+
+                        return configuration_item
+                    except:  # noqa: E722
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        configuration_item = ManifestIntegerScalarConfig.from_dict(data, strict=True)
+
+                        return configuration_item
+                    except:  # noqa: E722
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        configuration_item = ManifestBooleanScalarConfig.from_dict(data, strict=True)
+
+                        return configuration_item
+                    except:  # noqa: E722
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        configuration_item = ManifestDateScalarConfig.from_dict(data, strict=True)
+
+                        return configuration_item
+                    except:  # noqa: E722
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        configuration_item = ManifestDatetimeScalarConfig.from_dict(data, strict=True)
+
+                        return configuration_item
+                    except:  # noqa: E722
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        configuration_item = ManifestSecureTextScalarConfig.from_dict(data, strict=True)
+
+                        return configuration_item
+                    except:  # noqa: E722
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        configuration_item = ManifestJsonScalarConfig.from_dict(data, strict=True)
 
                         return configuration_item
                     except:  # noqa: E722
@@ -444,8 +556,15 @@ class BenchlingAppManifestAlpha:
                             WorkflowTaskSchemaDependency,
                             DropdownDependency,
                             ResourceDependency,
-                            ManifestScalarConfig,
                             ManifestArrayConfig,
+                            ManifestTextScalarConfig,
+                            ManifestFloatScalarConfig,
+                            ManifestIntegerScalarConfig,
+                            ManifestBooleanScalarConfig,
+                            ManifestDateScalarConfig,
+                            ManifestDatetimeScalarConfig,
+                            ManifestSecureTextScalarConfig,
+                            ManifestJsonScalarConfig,
                             UnknownType,
                         ]
                     ],
@@ -572,8 +691,15 @@ class BenchlingAppManifestAlpha:
             WorkflowTaskSchemaDependency,
             DropdownDependency,
             ResourceDependency,
-            ManifestScalarConfig,
             ManifestArrayConfig,
+            ManifestTextScalarConfig,
+            ManifestFloatScalarConfig,
+            ManifestIntegerScalarConfig,
+            ManifestBooleanScalarConfig,
+            ManifestDateScalarConfig,
+            ManifestDatetimeScalarConfig,
+            ManifestSecureTextScalarConfig,
+            ManifestJsonScalarConfig,
             UnknownType,
         ]
     ]:
@@ -591,8 +717,15 @@ class BenchlingAppManifestAlpha:
                 WorkflowTaskSchemaDependency,
                 DropdownDependency,
                 ResourceDependency,
-                ManifestScalarConfig,
                 ManifestArrayConfig,
+                ManifestTextScalarConfig,
+                ManifestFloatScalarConfig,
+                ManifestIntegerScalarConfig,
+                ManifestBooleanScalarConfig,
+                ManifestDateScalarConfig,
+                ManifestDatetimeScalarConfig,
+                ManifestSecureTextScalarConfig,
+                ManifestJsonScalarConfig,
                 UnknownType,
             ]
         ],
