@@ -25,6 +25,7 @@ class RnaOligoWithEntityType:
     _entity_type: Union[Unset, RnaOligoWithEntityTypeEntityType] = UNSET
     _api_url: Union[Unset, str] = UNSET
     _bases: Union[Unset, str] = UNSET
+    _helm: Union[Unset, str] = UNSET
     _nucleotide_type: Union[Unset, OligoNucleotideType] = UNSET
     _aliases: Union[Unset, List[str]] = UNSET
     _archive_record: Union[Unset, None, ArchiveRecord] = UNSET
@@ -49,6 +50,7 @@ class RnaOligoWithEntityType:
         fields.append("entity_type={}".format(repr(self._entity_type)))
         fields.append("api_url={}".format(repr(self._api_url)))
         fields.append("bases={}".format(repr(self._bases)))
+        fields.append("helm={}".format(repr(self._helm)))
         fields.append("nucleotide_type={}".format(repr(self._nucleotide_type)))
         fields.append("aliases={}".format(repr(self._aliases)))
         fields.append("archive_record={}".format(repr(self._archive_record)))
@@ -76,6 +78,7 @@ class RnaOligoWithEntityType:
 
         api_url = self._api_url
         bases = self._bases
+        helm = self._helm
         nucleotide_type: Union[Unset, int] = UNSET
         if not isinstance(self._nucleotide_type, Unset):
             nucleotide_type = self._nucleotide_type.value
@@ -133,6 +136,8 @@ class RnaOligoWithEntityType:
             field_dict["apiURL"] = api_url
         if bases is not UNSET:
             field_dict["bases"] = bases
+        if helm is not UNSET:
+            field_dict["helm"] = helm
         if nucleotide_type is not UNSET:
             field_dict["nucleotideType"] = nucleotide_type
         if aliases is not UNSET:
@@ -214,6 +219,17 @@ class RnaOligoWithEntityType:
                 raise
             bases = cast(Union[Unset, str], UNSET)
 
+        def get_helm() -> Union[Unset, str]:
+            helm = d.pop("helm")
+            return helm
+
+        try:
+            helm = get_helm()
+        except KeyError:
+            if strict:
+                raise
+            helm = cast(Union[Unset, str], UNSET)
+
         def get_nucleotide_type() -> Union[Unset, OligoNucleotideType]:
             nucleotide_type = UNSET
             _nucleotide_type = d.pop("nucleotideType")
@@ -451,6 +467,7 @@ class RnaOligoWithEntityType:
             entity_type=entity_type,
             api_url=api_url,
             bases=bases,
+            helm=helm,
             nucleotide_type=nucleotide_type,
             aliases=aliases,
             archive_record=archive_record,
@@ -536,6 +553,21 @@ class RnaOligoWithEntityType:
     def bases(self) -> None:
         self._bases = UNSET
 
+    @property
+    def helm(self) -> str:
+        """ Representation of the oligo in HELM syntax, including any chemical modifications """
+        if isinstance(self._helm, Unset):
+            raise NotPresentError(self, "helm")
+        return self._helm
+
+    @helm.setter
+    def helm(self, value: str) -> None:
+        self._helm = value
+
+    @helm.deleter
+    def helm(self) -> None:
+        self._helm = UNSET
+
     @property
     def nucleotide_type(self) -> OligoNucleotideType:
         """ Nucleotide type of the Oligo. """
